#[repr(transparent)]pub struct CounterVal(pub u32);Expand description
no description available
Tuple Fields
0: u32Implementations
Sourceimpl CounterVal
impl CounterVal
Sourcepub const fn clk_ratio(&self) -> u8
pub const fn clk_ratio(&self) -> u8
Gives the ratio between the internal clocks frequencies and the register clock frequency for evaluation and certification purposes.
Sourcepub const fn set_clk_ratio(&mut self, val: u8)
pub const fn set_clk_ratio(&mut self, val: u8)
Gives the ratio between the internal clocks frequencies and the register clock frequency for evaluation and certification purposes.
Sourcepub const fn refresh_cnt(&self) -> u8
pub const fn refresh_cnt(&self) -> u8
Incremented (till max possible value) each time COUNTER was updated since last reading to any *_NUMBER.
Sourcepub const fn set_refresh_cnt(&mut self, val: u8)
pub const fn set_refresh_cnt(&mut self, val: u8)
Incremented (till max possible value) each time COUNTER was updated since last reading to any *_NUMBER.