nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

OnlineTestCfg

Struct OnlineTestCfg 

#[repr(transparent)]
pub struct OnlineTestCfg(pub u32);
no description available

Tuple Fields

0: u32

Implementations

Source

impl OnlineTestCfg

pub const fn activate(&self) -> bool

0: disabled 1: activated Update rythm for VAL depends on COUNTER_CFG if data_sel is set to COUNTER.

pub const fn set_activate(&mut self, val: bool)

0: disabled 1: activated Update rythm for VAL depends on COUNTER_CFG if data_sel is set to COUNTER.

pub const fn data_sel(&self) -> u8

Selects source on which to apply online test: 00: LSB of COUNTER: raw data from one or all sources of entropy 01: MSB of COUNTER: raw data from one or all sources of entropy 10: RANDOM_NUMBER 11: ENCRYPTED_NUMBER ‘activate’ should be set to ‘disabled’ before changing this field.

pub const fn set_data_sel(&mut self, val: u8)

Selects source on which to apply online test: 00: LSB of COUNTER: raw data from one or all sources of entropy 01: MSB of COUNTER: raw data from one or all sources of entropy 10: RANDOM_NUMBER 11: ENCRYPTED_NUMBER ‘activate’ should be set to ‘disabled’ before changing this field.