nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

OnlineTestVal

Struct OnlineTestVal 

#[repr(transparent)]
pub struct OnlineTestVal(pub u32);
no description available

Tuple Fields

0: u32

Implementations

Source

impl OnlineTestVal

pub const fn live_chi_squared(&self) -> u8

This value is updated as described in field ‘activate’.

pub const fn set_live_chi_squared(&mut self, val: u8)

This value is updated as described in field ‘activate’.

pub const fn min_chi_squared(&self) -> u8

This field is reset when ‘activate’==0.

pub const fn set_min_chi_squared(&mut self, val: u8)

This field is reset when ‘activate’==0.

pub const fn max_chi_squared(&self) -> u8

This field is reset when ‘activate’==0.

pub const fn set_max_chi_squared(&mut self, val: u8)

This field is reset when ‘activate’==0.