#[repr(transparent)]pub struct RandomNumber(pub u32);Expand description
This register contains a random 32 bit number which is computed on demand, at each time it is read
Tuple Fields
0: u32Implementations
Sourceimpl RandomNumber
impl RandomNumber
Sourcepub const fn random_number(&self) -> u32
pub const fn random_number(&self) -> u32
This register contains a random 32 bit number which is computed on demand, at each time it is read.
Sourcepub const fn set_random_number(&mut self, val: u32)
pub const fn set_random_number(&mut self, val: u32)
This register contains a random 32 bit number which is computed on demand, at each time it is read.