#[repr(transparent)]pub struct OnlineTestCfg(pub u32);Expand description
no description available
Tuple Fields
0: u32Implementations
Sourceimpl OnlineTestCfg
impl OnlineTestCfg
Sourcepub const fn activate(&self) -> bool
pub const fn activate(&self) -> bool
0: disabled 1: activated Update rythm for VAL depends on COUNTER_CFG if data_sel is set to COUNTER.
Sourcepub const fn set_activate(&mut self, val: bool)
pub const fn set_activate(&mut self, val: bool)
0: disabled 1: activated Update rythm for VAL depends on COUNTER_CFG if data_sel is set to COUNTER.
Sourcepub const fn data_sel(&self) -> u8
pub const fn data_sel(&self) -> u8
Selects source on which to apply online test: 00: LSB of COUNTER: raw data from one or all sources of entropy 01: MSB of COUNTER: raw data from one or all sources of entropy 10: RANDOM_NUMBER 11: ENCRYPTED_NUMBER ‘activate’ should be set to ‘disabled’ before changing this field.
Sourcepub const fn set_data_sel(&mut self, val: u8)
pub const fn set_data_sel(&mut self, val: u8)
Selects source on which to apply online test: 00: LSB of COUNTER: raw data from one or all sources of entropy 01: MSB of COUNTER: raw data from one or all sources of entropy 10: RANDOM_NUMBER 11: ENCRYPTED_NUMBER ‘activate’ should be set to ‘disabled’ before changing this field.