#[repr(transparent)]pub struct OnlineTestVal(pub u32);Expand description
no description available
Tuple Fields
0: u32Implementations
Sourceimpl OnlineTestVal
impl OnlineTestVal
Sourcepub const fn live_chi_squared(&self) -> u8
pub const fn live_chi_squared(&self) -> u8
This value is updated as described in field ‘activate’.
Sourcepub const fn set_live_chi_squared(&mut self, val: u8)
pub const fn set_live_chi_squared(&mut self, val: u8)
This value is updated as described in field ‘activate’.
Sourcepub const fn min_chi_squared(&self) -> u8
pub const fn min_chi_squared(&self) -> u8
This field is reset when ‘activate’==0.
Sourcepub const fn set_min_chi_squared(&mut self, val: u8)
pub const fn set_min_chi_squared(&mut self, val: u8)
This field is reset when ‘activate’==0.
Sourcepub const fn max_chi_squared(&self) -> u8
pub const fn max_chi_squared(&self) -> u8
This field is reset when ‘activate’==0.
Sourcepub const fn set_max_chi_squared(&mut self, val: u8)
pub const fn set_max_chi_squared(&mut self, val: u8)
This field is reset when ‘activate’==0.